require_dependency "lra_client/application_controller"
require 'net/http'

module LraClient
  class LraController < ApplicationController

    def login
      result = send_post_request(
        LraClient.request_challenge_url,
        app_id: LraClient.app_id,
        key: LraClient.key,
        return_url: LraClient.return_url
      )

      if result['success']
        redirect_to result['login_url']
      else
        raise "[LRA] #{result['errors'].first}"
      end
    end

    def return
      result = send_post_request(
        LraClient.load_details_url,
        app_id: LraClient.app_id,
        key: LraClient.key,
        answer: params[:answer]
      )

      if result['success']
        user = LraClient::User.create_or_update_from_loft(result)
        session[:current_user_id] = user.id
        session[:current_user_type] = 'LraClient::User'
      else
        raise "[LRA] #{result['errors'].first}"
      end

      redirect_to LraClient.login_completion_url
    end

    private

    def send_post_request(url, data)
      uri = URI.parse(url)
      req = Net::HTTP::Post.new(uri.path)
      req.form_data = data
      con = Net::HTTP.new(uri.host, uri.port)
      con.use_ssl = true
      result = con.start { |https| https.request(req) }
      JSON.parse(result.body)
    end
  end
end
